@@ -41,7 +41,8 @@ from pre_workbench.datawidgets import DynamicDataWidget
 from pre_workbench.util import get_app_version, SimpleThread
 from pre_workbench.windows.dialogs.manageannotationsets import ManageAnnotationSetsDialog
 from pre_workbench.windows.dockwindows import FileBrowserWidget, MdiWindowListWidget, StructInfoTreeWidget, \
-	StructInfoCodeWidget, DataInspectorWidget, BinwalkDockWidget, ExtToolDockWidget, SearchDockWidget
+	StructInfoCodeWidget, DataInspectorWidget, BinwalkDockWidget, ExtToolDockWidget, SearchDockWidget, \
+	MacroListDockWidget
 from pre_workbench.windows.dockwindows import RangeTreeDockWidget, RangeListWidget, SelectionHeuristicsConfigWidget, LogWidget
 from pre_workbench.controls.genericwidgets import MemoryUsageWidget, showPreferencesDlg
 from pre_workbench.typeeditor import JsonView
@@ -106,11 +107,20 @@ class WorkbenchMain(QMainWindow):
 	def closeEvent(self, e):
 		configs.setValue("MainWindowGeometry", self.saveGeometry())
 		configs.setValue("MainWindowState", self.saveState(123))
-		self.saveChildren()
+		if not self._checkDirtyChildren():
+			e.ignore()
+		self._saveChildrenState()
 		self.project.setValue("DockState", self.mdiArea.saveState())
 		super().closeEvent(e)
 
-	def saveChildren(self):
+	def _checkDirtyChildren(self):
+		for wnd in self.mdiArea.dockWidgetsMap().values():
+			if hasattr(wnd.widget(), "maybeSave"):
+				if not wnd.widget().maybeSave():
+					return False
+		return True
+
+	def _saveChildrenState(self):
 		self.project.setValue("ChildrenInfo", [
 			{
 				"id": wnd.widget().objectName(),
@@ -207,8 +217,6 @@ class WorkbenchMain(QMainWindow):
 		self.manageAnnotationSetsAct = QAction("&Manage Annotation Sets", self,
 				triggered=lambda: ManageAnnotationSetsDialog(self).exec())
 
-
-
 	def _initMenu(self):
 		menubar = self.menuBar()
 		mainToolbar = self.addToolBar('Main')
@@ -221,9 +229,10 @@ class WorkbenchMain(QMainWindow):
 		newTbAct.setMenu(newTbMenu)
 		for wndTyp, meta in WindowTypes.types:
 			text = 'New '+meta.get('displayName', meta.get('name'))
-			newAct = QAction(text, self, #shortcut='Ctrl+N',
-									   statusTip=text,
+			newAct = QAction(text, self, statusTip=text,
 									   triggered=lambda dummy, wndTyp=wndTyp: self.onFileNewWindowAction(wndTyp))
+			if wndTyp.__name__ == 'TextFileWindow': newAct.setShortcut('Ctrl+Shift+N')
+			if wndTyp.__name__ == 'ObjectWindow': newAct.setShortcut('Ctrl+N')
 			#fileMenu.addAction(newAct)
 			newTbMenu.addAction(newAct)
 		mainToolbar.addWidget(newTbAct)
@@ -345,8 +354,10 @@ class WorkbenchMain(QMainWindow):
 
 		self.createDockWnd("Selection Heuristics", "table-select-cells.png", SelectionHeuristicsConfigWidget())
 
-		self.createDockWnd("Binwalk", "regular-expression-search-match.png", BinwalkDockWidget(), ads.BottomDockWidgetArea, showFirstRun=False)
-		self.selected_bytes_updated.connect(self.dockWidgets["Binwalk"].on_select_bytes)
+		#self.createDockWnd("Binwalk", "regular-expression-search-match.png", BinwalkDockWidget(), ads.BottomDockWidgetArea, showFirstRun=False)
+		#self.selected_bytes_updated.connect(self.dockWidgets["Binwalk"].on_select_bytes)
+		self.createDockWnd("Macros", "regular-expression-search-match.png", MacroListDockWidget(),
+						   ads.RightDockWidgetArea, showFirstRun=False)
 
 		self.createDockWnd("External Tools", "toolbox--arrow.png", ExtToolDockWidget(), ads.BottomDockWidgetArea, showFirstRun=False)
 		self.selected_bytes_updated.connect(self.dockWidgets["External Tools"].on_select_bytes)
@@ -602,6 +613,7 @@ class WorkbenchMain(QMainWindow):
 		logging.debug("showChild %s", widget)
 		subwnd = ads.CDockWidget(widget.windowTitle())
 		subwnd.setWidget(widget)
+		widget.windowTitleChanged.connect(lambda newTitle: subwnd.setWindowTitle(newTitle))
 		subwnd.setFeature(ads.CDockWidget.DockWidgetDeleteOnClose, True)
 		subwnd.setFeature(ads.CDockWidget.DockWidgetForceCloseWithArea, True)
 		subwnd.setWindowIcon(getIcon(type(widget).icon if hasattr(type(widget), 'icon') else 'document.png'))
